#!/bin/bash

# Caminho para o arquivo de configuração do Zabbix Agent
ZABBIX_CONFIG="/ariusmonitor/conf/zabbix_agentd.conf"

# Lê o Hostname definido no arquivo de configuração do Zabbix Agent
HOSTNAME=$(grep "^Hostname=" $ZABBIX_CONFIG | cut -d'=' -f2 | tr -d '[:space:]')

# Extrai os códigos de Loja e PDV do Hostname, usando apenas os dois últimos dígitos de cada um
LOJA_CODE=$(echo "$HOSTNAME" | grep -oP 'LOJA\d+' | grep -oP '\d+' | tail -c3 | head -c2)
PDV_CODE=$(echo "$HOSTNAME" | grep -oP 'PDV\d+' | grep -oP '\d+' | tail -c3 | head -c2)

# Encontra o arquivo do operador mais recente
OPERADOR_FILE=$(find /posnet/ -name 'OPER_*.pdv' -mmin -$((24*60)) ! -name 'OPER_001000.pdv' 2>/dev/null | tail -n 1)

if [ -z "$OPERADOR_FILE" ]; then
  exit 0
fi

# Extrai o código do operador do nome do arquivo, esperando-se que sejam os 4 últimos dígitos
OPERADOR_CODE=$(echo "$OPERADOR_FILE" | grep -o 'OPER_[0-9]*\.pdv' | sed 's/OPER_//' | sed 's/\.pdv//' | awk '{print substr($0, length-3)}')

# Compara os códigos extraídos do Hostname e do nome do arquivo do operador
if [[ "${LOJA_CODE}${PDV_CODE}" == "$OPERADOR_CODE" ]]; then
  echo 1  # Sucesso, os códigos correspondem
else
  echo 0  # Falha, os códigos não correspondem
fi
